@@ -300,7 +300,7 @@
                 </div>
             </div>
             <div class="modal-footer"> 
-                 <button type="button" data-dismiss="modal" class="btn-cancel">Cancel</button>
+                 <button type="button" data-dismiss="modal" class="btn-cancel">Close</button>
             </div>
         </div>                                                                                                                     
     </div>
@@ -333,14 +333,23 @@ function addform(){
         $('#StartingMonth').val("0"); 
         $('#EndingYear').val("0"); 
         $('#EndingMonth').val("0"); 
-        $('#Remarks').val(""); 
-         $("#Code").removeClass("highlight_error");
-         $("#BatchName").removeClass("highlight_error");
-         $("#StartingYear").removeClass("highlight_error");
-         $("#StartingMonth").removeClass("highlight_error");
-         $("#EndingYear").removeClass("highlight_error");
-         $("#EndingMonth").removeClass("highlight_error");
-         $("#Remarks").removeClass("highlight_error");
+        $('#Remarks').val("");
+        
+        $('#ErrCode').html("");
+        $('#ErrBatchName').html(""); 
+        $('#ErrStartingYear').html(""); 
+        $('#ErrStartingMonth').html(""); 
+        $('#ErrEndingYear').html(""); 
+        $('#ErrEndingMonth').html(""); 
+        $('#ErrRemarks').html(""); 
+         
+        $("#Code").removeClass("highlight_error");
+        $("#BatchName").removeClass("highlight_error");
+        $("#StartingYear").removeClass("highlight_error");
+        $("#StartingMonth").removeClass("highlight_error");
+        $("#EndingYear").removeClass("highlight_error");
+        $("#EndingMonth").removeClass("highlight_error");
+        $("#Remarks").removeClass("highlight_error");
 }
 
 function add(){
