@@ -42,22 +42,7 @@
             </div>
             </div>
 </div>
-<div class="modal fade" id="confirmation" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-backdrop="static">
-    <div class="modal-dialog modal-dialog-centered">
-        <div class="modal-content">
-            <div class="modal-header">
-                <h5 class="modal-title" id="exampleModalLabel">Confirmation</h5>
-                <button type="button" class="btn-close" data-dismiss="modal"></button>
-            </div>
-            <div class="modal-body">
-                Successfully done.
-            </div>
-            <div class="modal-footer">
-                 <button type="button" href="javascript:void(0)" onclick="dashboard()" class="btn-cancel">Continue</button>
-            </div>
-        </div>                                                                                                                     
-    </div>
-</div>
+
 
 <div class="modal fade" id="confirmationtoadd" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-backdrop="static">
     <div class="modal-dialog modal-dialog-centered">
@@ -75,7 +60,7 @@
                     </div>
                     <div class="col-12">
                         <label class="form-label">Course Type</label><span style='color:red'>*</span>
-                         <select class="form-select form-select-sm" name="CourseType" id="CourseType" onkeypress="clearInput('CourseType')">
+                         <select class="form-select form-select-sm" name="CourseType" id="CourseType" onchange="clearInput('CourseType')">
                             <option value="0">Select Course Type</option>
                             <option value="1">Course Type 1</option>
                          </select>
@@ -117,7 +102,7 @@
                     </div>
                      <div class="col-12">
                         <label class="form-label">Course Type</label><span style='color:red'>*</span>
-                         <select class="form-select form-select-sm" name="CourseType" id="editCourseType" value="<?php echo $data[0]['CourseType'];?>"  onkeypress="clearInput('editCourseType')">
+                         <select class="form-select form-select-sm" name="CourseType" id="editCourseType" value="<?php echo $data[0]['CourseType'];?>"  onchange="clearInput('editCourseType')">
                          <option value="0">Select Course Type</option>
                          <option value="1">Course Type 1</option>
                          </select>
@@ -186,7 +171,7 @@
                 </div>
             </div>
             <div class="modal-footer"> 
-                 <button type="button" data-dismiss="modal" class="btn-cancel">Cancel</button>
+                 <button type="button" data-dismiss="modal" class="btn-cancel">Close</button>
             </div>
         </div>                                                                                                                     
     </div>
@@ -199,7 +184,7 @@
                     <img id="Sucess" style="width: 150px;" src="assets/sucess.gif" alt=""/>
                 </div>
                 <h3 class="title">Success.</h3>  
-                 <button type="button" href="javascript:void(0)" onclick="dashboard()" class="btn-save">Continue</button>         
+                 <button type="button" href="javascript:void(0)" onclick="list()" class="btn-save">Continue</button>         
             </div>
         </div>
     </div>
@@ -217,6 +202,12 @@ function addform(){
         $('#CourseName').val("");
         $('#Remarks').val("");
         $('#CourseType').val("0");
+        
+        $('#ErrCode').html("");
+        $('#ErrCourseName').html(""); 
+        $('#ErrCourseType').html(""); 
+        $('#ErrRemarks').html(""); 
+        
         $("#Code").removeClass("highlight_error");  
         $("#CourseName").removeClass("highlight_error");  
         $("#CourseType").removeClass("highlight_error");  
@@ -258,6 +249,10 @@ function add(){
 
 function editform(){
      $('#confirmationtoedit').modal("show"); 
+     $('#ErreditCode').html("");
+     $('#ErreditCourseName').html(""); 
+     $('#ErreditCourseType').html(""); 
+     $('#ErreditRemarks').html(""); 
      $("#editCode").removeClass("highlight_error");  
      $("#editCourseName").removeClass("highlight_error");  
      $("#editCourseType").removeClass("highlight_error");  
