@@ -1,59 +1,32 @@
-            <div class="user-dashboard">
-                <div class="container">
-                <div class="col-xl-12 col-lg-12">
-                    <div class="row">
-                        <div class="col-6"> 
-                            <h3>Semester</h3>
-                         </div>
-                         <div class="col-6" style="text-align: right;"> 
-                            <button class="btn-save" onclick="addform()">New</button>
-                         </div>
-                        </div>                                                 
-                        </div>
-                   <div class="row">
-                <div class="col-xl-12 col-lg-12">
-                    <div class="transactions-table table">
-                        <div class="table">
-                            <table id="example" class="table" style="width:100%">
-                                <thead>
-                                    <tr>
-                                        <th>Code</th>
-                                        <th>Semester Name</th>
-                                        <th>Status</th>
-                                        <th></th>
-                                        <th></th>
-                                    </tr>
-                                </thead>
-                                <tbody>
-                                     <tr>
-                                        <td></td>                                                          
-                                        <td></td>           
-                                        <td></td>
-                                        <td style="width: 70px;"><a href="javascript:void(0)" onclick="editform()" class="btn-save">Edit</a></td>
-                                        <td style="width: 70px;"><a href="javascript:void(0)" onclick="viewform()" class="btn-save">View</a></td>
-                                     </tr>
-                                   </tbody>
-                            </table>
-                        </div>
-                    </div>
-                </div>
+<div class="user-dashboard">
+    <div class="container">
+        <div class="row">
+            <div class="col-6"> 
+                <h3>Semesters</h3>
             </div>
+            <div class="col-6" style="text-align: right;"> 
+                <button class="btn-save" onclick="addform()">New</button>
             </div>
-</div>
-<div class="modal fade" id="confirmation" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-backdrop="static">
-    <div class="modal-dialog modal-dialog-centered">
-        <div class="modal-content">
-            <div class="modal-header">
-                <h5 class="modal-title" id="exampleModalLabel">Confirmation</h5>
-               <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
+            <div class="col-xl-12 col-lg-12">
+                <table id="listTable" class="table" style="width:100%">
+                    <thead>
+                        <tr>
+                            <th style="width:150px">Code</th>
+                            <th>Semester</th>
+                            <th style="width:50px">Status</th>
+                            <th style="width:100px"></th>
+                        </tr>
+                    </thead>                                     
+                    <tbody id="tbl_content">
+                        <tr>
+                            <td colspan='4'>
+                                <?php echo loadingText("Loading Semesters");?>
+                            </td>
+                        </tr>
+                    </tbody>
+                </table>
             </div>
-            <div class="modal-body">
-                Successfully done.
-            </div>
-            <div class="modal-footer">
-                 <button type="button" href="javascript:void(0)" onclick="dashboard()" class="btn-save">Continue</button>
-            </div>
-        </div>                                                                                                                     
+        </div>
     </div>
 </div>
 
@@ -65,16 +38,18 @@
                 <button type="button" class="btn-close" data-dismiss="modal"></button>
             </div>
             <div class="modal-body">
-                <div class="row">
+                 <form id="frm_create" name="frm_create" method="post" enctype="multipart/form-data" autocomplete="off">
+                  <div class="row">
+                     <span id="ErrCommon"></span>
                     <div class="col-6">
                         <label class="form-label">Code</label><span style='color:red'>*</span>
                         <input class="form-control form-control-sm" type="text" id="Code" name="Code" placeholder="Code" value="" onkeypress="clearInput('Code')">
                         <span id="ErrCode" class="error_msg" style="color: red;"></span>
                     </div>
                     <div class="col-12">
-                        <label class="form-label">Semester Name</label><span style='color:red'>*</span>
-                         <input class="form-control form-control-sm" type="text" name="SemesterName" id="SemesterName" placeholder="Semester Name" onkeypress="clearInput('SemesterName')">
-                        <span id="ErrSemesterName" class="error_msg" style="color: red;"></span>
+                        <label class="form-label">Semester</label><span style='color:red'>*</span>
+                         <input class="form-control form-control-sm" type="text" name="Semester" id="Semester" placeholder="Semester" onkeypress="clearInput('Semester')">
+                        <span id="ErrSemester" class="error_msg" style="color: red;"></span>
                     </div>
                     <div class="col-12">
                         <label class="form-label">Remarks</label>
@@ -82,6 +57,7 @@
                         <span id="ErrRemarks" class="error_msg" style="color: red;"></span>
                     </div>
                 </div>
+                 </form>
             </div>
             <div class="modal-footer">
                  <button type="button" data-dismiss="modal" class="btn-cancel">Cancel</button>
@@ -99,30 +75,34 @@
                <button type="button" class="btn-close" data-dismiss="modal"></button>
             </div>
             <div class="modal-body">
+            <form id="frm_edit" name="frm_edit" method="post" enctype="multipart/form-data" autocomplete="off">
+                <input type="hidden" name="ID" id="editID">
                 <div class="row">
+                      <span id="ErreditCommon"></span>
                     <div class="col-6">
                         <label class="form-label">Code</label><span style='color:red'>*</span>
-                        <input class="form-control form-control-sm" type="text" id="editCode" name="Code" placeholder="Code" value="<?php echo $data[0]['Code'];?>" onkeypress="clearInput('editCode')">
+                        <input class="form-control form-control-sm" type="text" id="editCode" name="Code" placeholder="Code" value="" onkeypress="clearInput('editCode')">
                         <span id="ErreditCode" class="error_msg" style="color: red;"></span>
                     </div>
                      <div class="col-12">
-                        <label class="form-label">Semester Name</label><span style='color:red'>*</span>
-                         <input class="form-control form-control-sm" type="text" name="SemesterName" id="editSemesterName" placeholder="Semester Name" value="<?php echo $data[0]['SemesterName'];?>" onkeypress="clearInput('editSemesterName')">
-                        <span id="ErreditSemesterName" class="error_msg" style="color: red;"></span>
+                        <label class="form-label">Semester</label><span style='color:red'>*</span>
+                         <input class="form-control form-control-sm" type="text" name="Semester" id="editSemester" placeholder="Semester" value="" onkeypress="clearInput('editSemester')">
+                        <span id="ErreditSemester" class="error_msg" style="color: red;"></span>
                     </div>
                     <div class="col-sm-6">
                         <label class="form-label">Status</label>
                         <select name="Status" id="editStatus" class="form-select form-select-sm">
-                            <option value="1" <?php echo ($data[0]['Status']==1) ? " selected='selected' ": "''";?>>Active</option>
-                            <option value="0" <?php echo ($data[0]['Status']==0) ? " selected='selected' ": "''";?>>DeActive</option>
+                            <option value="1">Active</option>
+                            <option value="0">Deactive</option>
                         </select>
                     </div>
                     <div class="col-12">
                         <label class="form-label">Remarks</label>
-                        <input class="form-control form-control-sm" type="text" id="editRemarks" name="Remarks" placeholder="Remarks" value="<?php echo $data[0]['Remarks'];?>" onkeypress="clearInput('editRemarks')">
+                        <input class="form-control form-control-sm" type="text" id="editRemarks" name="Remarks" placeholder="Remarks" value="" onkeypress="clearInput('editRemarks')">
                         <span id="ErreditRemarks" class="error_msg" style="color: red;"></span>
                     </div>
                 </div>
+            </form>
             </div>
             <div class="modal-footer">
                 <button type="button" data-dismiss="modal" class="btn-cancel">Cancel</button>
@@ -143,28 +123,28 @@
                 <div class="row">
                     <div class="col-sm-6">
                         <div style="font-weight: bold;">Code</div>
-                        <?php echo $data[0]['Code'];?>
+                         <div id="viewCode"></div>
                     </div>
                     <div class="col-sm-12">
-                        <div style="font-weight: bold;">Semester Name</div>
-                        <?php echo $data[0]['SemesterName'];?>
+                        <div style="font-weight: bold;">Semester</div>
+                         <div id="viewSemester"></div>
                     </div>
                     <div class="col-sm-12">
                         <div style="font-weight: bold;">Remarks</div>
-                        <?php echo $data[0]['Remarks'];?>
+                         <div id="viewRemarks"></div>
                     </div>
                     <div class="col-sm-6">
                         <div style="font-weight: bold;">Status</div>
-                        <?php echo $data[0]['IsActive'];?>
+                         <div id="viewStatus"></div>
                     </div>
                     <div class="col-sm-6">
                         <div style="font-weight: bold;">Created On</div>
-                        <?php echo $data[0]['CreatedOn'];?>
+                         <div id="viewCreatedOn"></div>
                     </div>
                 </div>
             </div>
             <div class="modal-footer"> 
-                 <button type="button" data-dismiss="modal" class="btn-cancel">Cancel</button>
+                 <button type="button" data-dismiss="modal" class="btn-cancel">Close</button>
             </div>
         </div>                                                                                                                     
     </div>
@@ -177,24 +157,59 @@
                     <img id="Sucess" style="width: 150px;" src="assets/sucess.gif" alt=""/>
                 </div>
                 <h3 class="title">Success.</h3>  
-                 <button type="button" href="javascript:void(0)" onclick="dashboard()" class="btn-save">Continue</button>         
+                 <button type="button" href="javascript:void(0)" onclick="list()" class="btn-save">Continue</button>         
             </div>
         </div>
     </div>
 </div>
      
 <script>
-function view(){
-      $('#confirmation').modal("show"); 
+function list() {
+      $('#Success').modal("hide");
+    $.post(URL+ "webservice.php?action=l&method=masl","",function(data){
+      var obj = JSON.parse(data);
+        if (obj.status=="success") {
+            var html = "";
+            i=0;
+            $.each(obj.data, function (index, data) {
+                html += '<tr class="'+((i%2!=0) ? 'rEven' : 'rOdd')+'">'
+                            + '<td>' + data.Code + '</td>'
+                            + '<td>' + data.Semester + '</td>' 
+                            + '<td>' + ( (data.Status=="1") ? "<span class='badge bg-success'>Active</span>" : "<span class='badge bg-secondary'>Deactive</span>" ) + '</td>'
+                             + '<td style="text-align:right">' 
+                                + '<span onclick="editform(\''+data.ID+'\')" class="editLink"  title="Edit Record"><i class="fi fi-rs-pencil"></i></span>&nbsp;&nbsp;'
+                               + '<span onclick="viewform(\''+data.ID+'\')" class="viewLink"  title="View Record"><i class="fi fi-rs-web-test"></i></span>&nbsp;&nbsp;'
+                               + '<span onclick="openDeleteConfirmation(\''+data.ID+'\',\'r\',\'masl\',\''+data.Semester+'\',\'l\')" class="deleteLink" title="Delete Record"><i class="fi fi-rs-trash"></i></span>'
+                               + '</td>'
+                             + '</tr>' 
+                      + '</tr>';
+                      i++;
+            });
+            if(obj.data.length==0){
+            html += '<tr>'
+                + '<td colspan="6" style="text-align: center;background:#fff !important">No data found</td>'
+                + '</tr>'
+            }   
+            $('#tbl_content').html(html);
+        } else {
+             $('#popupcontent').html( error(obj.message));
+        }  
+    });
 }
 
+setTimeout("list()",2000);
 function addform(){
      $('#confirmationtoadd').modal("show");
      $('#Code').val(""); 
-     $('#SemesterName').val("");
+     $('#Semester').val("");
      $('#Remarks').val("");
+     
+     $('#ErrCode').html("");
+     $('#ErrSemester').html(""); 
+     $('#ErrRemarks').html("");
+        
      $("#Code").removeClass("highlight_error"); 
-     $("#SemesterName").removeClass("highlight_error"); 
+     $("#Semester").removeClass("highlight_error"); 
      $("#Remarks").removeClass("highlight_error"); 
      
 }
@@ -209,29 +224,58 @@ function add(){
             $("#Code").removeClass("highlight_error"); 
             $('#ErrCode').html(""); 
     }
-    if ($('#SemesterName').val()==""){
-            $('#ErrSemesterName').html("Please enter Semester Name");
-        $("#SemesterName").addClass("highlight_error"); 
+    if ($('#Semester').val()==""){
+            $('#ErrSemester').html("Please enter Semester");
+        $("#Semester").addClass("highlight_error"); 
            error++;
     }  else {
-            $("#SemesterName").removeClass("highlight_error"); 
-            $('#ErrSemesterName').html(""); 
+            $("#Semester").removeClass("highlight_error"); 
+            $('#ErrSemester').html(""); 
     } 
-      if (error==0){
-       $('#confirmationtoadd').modal("hide"); 
-       $('#Success').modal("show");  
-    }
+     if(error==0){
+        var param = $('#frm_create').serialize();
+        $.post(URL+"webservice.php?action=a&method=masl",param,function(data){
+        var obj = JSON.parse(data); 
+        if (obj.status=="success") {
+             $('#confirmationtoadd').modal("hide"); 
+             $('#Success').modal("show");    
+        }   else {
+            $('#ErrCommon').html(print_inlineError(obj.message));
+        }
+    });
+   } 
    
 }
 
-function editform(){
-     $('#confirmationtoedit').modal("show"); 
+function editform(ID){
+     $('#confirmationtoedit').modal("show");
+    
+     $('#ErreditCode').html("");
+     $('#ErreditSemester').html(""); 
+     $('#ErreditRemarks').html("");
+      
      $("#editCode").removeClass("highlight_error"); 
-     $("#editSemesterName").removeClass("highlight_error"); 
+     $("#editSemester").removeClass("highlight_error"); 
      $("#editRemarks").removeClass("highlight_error");
+        $.post(URL+ "webservice.php?action=g&method=masl&ID="+ID,"",function(data){
+        var obj = JSON.parse(data);
+        if (obj.status=="success") {
+            var html = "";
+            $.each(obj.data, function (index, data) {
+                $('#editCode').val(data.Code);
+                $('#editID').val(data.ID);
+                $('#editSemester').val(data.Semester);
+                $('#editStatus').val(data.Status);
+                $('#editRemarks').val(data.Remarks);
+            });   
+}  
+        else {
+            $('#ErreditCommon').html(print_inlineError(obj.message));
+        }
+  });
 }
 
-function edit(){
+function edit(ID){
      var error = 0;
     if ($('#editCode').val()==""){
             $('#ErreditCode').html("Please enter Code");
@@ -241,30 +285,51 @@ function edit(){
             $("#editCode").removeClass("highlight_error");
             $('#ErreditCode').html(""); 
     }
-     if ($('#editSemesterName').val()==""){
-            $('#ErreditSemesterName').html("Please enter Semester Name");
-            $("#editSemesterName").addClass("highlight_error");
+     if ($('#editSemester').val()==""){
+            $('#ErreditSemester').html("Please enter Semester");
+            $("#editSemester").addClass("highlight_error");
           error++;
     }  else {
-            $("#editSemesterName").removeClass("highlight_error");
-            $('#ErreditSemesterName').html(""); 
+            $("#editSemester").removeClass("highlight_error");
+            $('#ErreditSemester').html(""); 
     } 
-      if (error==0){
-       $('#confirmationtoedit').modal("hide"); 
-       $('#Success').modal("show");  
-    }
-   
+  
+    if(error==0){
+            var param = $('#frm_edit').serialize();
+            $.post(URL+"webservice.php?action=u&method=masl",param,function(data){
+            var obj = JSON.parse(data); 
+            if (obj.status=="success") {
+                 $('#confirmationtoedit').modal("hide");
+                 $('#Success').modal("show");  
+            }   else {
+                $('#ErreditCommon').html(print_inlineError(obj.message));
+            }
+        });
+       } 
    
 }
 
-function viewform(){
+function viewform(ID){
      $('#confirmationtoview').modal("show"); 
+       $.post(URL+ "webservice.php?action=g&method=masl&ID="+ID,"",function(data){
+        var obj = JSON.parse(data);
+        if (obj.status=="success") {
+            $.each(obj.data, function (index, data) {
+                $('#viewCode').html(data.Code=="" ? "&nbsp;" : data.Code);
+                $('#viewSemester').html(data.Semester=="" ? "&nbsp" : data.Semester);
+                $('#viewRemarks').html(data.Remarks=="" ? "&nbsp;" : data.Remarks);
+                $('#viewCreatedOn').html(data.CreatedOn=="" ? "&nbsp;" : data.CreatedOn);
+               if(data.Status=="1"){
+                $('#viewStatus').html("Active");    
+               }
+               if(data.Status=="0"){
+                $('#viewStatus').html("Deactive");    
+               }
+            });   
+}  
+  })
 }
-
-
-function dashboard()  {
-  location.href='dashboard.php';                                                              
-}
+      
  
 //Character Limitations
 
@@ -297,7 +362,7 @@ for (var i=0; i<arr.length; i++) {
 }
 
 /* Alphanumeric Space only correct */ 
-var arr = ["SemesterName","editSemesterName"];
+var arr = ["Semester","editSemester"];
 for (var i=0; i<arr.length; i++) {
     if ($('#'+arr[i]).length){
         document.getElementById(arr[i]).addEventListener("keydown",function(e) {   
@@ -306,8 +371,8 @@ for (var i=0; i<arr.length; i++) {
             if (e.ctrlKey || e.altKey) {
                 e.preventDefault();
             } else {
-               var notallowkeys = [48,49,50,51,52,53,54,55,56,57,188,191,59,220,221,222,219,173,61,192,111,106,109,107,46,190]
-                var allowedkeys  = [32,96,97,98,99,100,101,102,103,104,105,9,8,16,46,35,36,37,38,39,40,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,48,49,50,51,52,53,54,55,56,57,33,34,35,36,37,38,39,40,45,12]
+               var notallowkeys = [48,49,50,51,52,53,54,55,56,57,188,191,59,220,221,222,219,173,61,192,111,106,109,107,46]
+                var allowedkeys  = [190,32,96,97,98,99,100,101,102,103,104,105,9,8,16,46,35,36,37,38,39,40,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,48,49,50,51,52,53,54,55,56,57,33,34,35,36,37,38,39,40,45,12]
                 if (e.shiftKey) {
                     if (notallowkeys.includes(keyCode)) {
                         e.preventDefault();
