@@ -1,63 +1,37 @@
-
-            <div class="user-dashboard">
-                <div class="container">
-                <div class="col-xl-12 col-lg-12">
-                    <div class="row">
-                        <div class="col-6"> 
-                            <h3>University</h3>
-                         </div>
-                         <div class="col-6" style="text-align: right;"> 
-                            <button class="btn-save" onclick="addform()">New</button>
-                         </div>
-                        </div>                                                 
-                        </div>
-                   <div class="row">
-                <div class="col-xl-12 col-lg-12">
-                    <div class="transactions-table table">
-                        <div class="table">
-                            <table id="example" class="table" style="width:100%">
-                                <thead>
-                                    <tr>
-                                        <th>Code</th>
-                                        <th>University Name</th>
-                                        <th>Status</th>
-                                        <th></th>
-                                        <th></th>
-                                    </tr>
-                                </thead>
-                                <tbody>
-                                     <tr>
-                                        <td></td>                                                          
-                                        <td></td>           
-                                        <td></td>
-                                        <td style="width: 70px;"><a href="javascript:void(0)" onclick="editform()" class="btn-save">Edit</a></td>
-                                        <td style="width: 70px;"><a href="javascript:void(0)" onclick="viewform()" class="btn-save">View</a></td>
-                                     </tr>
-                                   </tbody>
-                            </table>
-                        </div>
-                    </div>
-                </div>
+<div class="user-dashboard">
+    <div class="container">
+        <div class="row">
+            <div class="col-6"> 
+                <h3>University Names</h3>
             </div>
+            <div class="col-6" style="text-align: right;"> 
+                <button class="btn-save" onclick="addform()">New</button>
             </div>
-</div>
-<div class="modal fade" id="confirmation" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-backdrop="static">
-    <div class="modal-dialog modal-dialog-centered">
-        <div class="modal-content">
-            <div class="modal-header">
-                <h5 class="modal-title" id="exampleModalLabel">Confirmation</h5>
-                 <button type="button" class="btn-close" data-dismiss="modal"></button>
+            <div class="col-xl-12 col-lg-12">
+                <table id="listTable" class="table" style="width:100%">
+                    <thead>
+                        <tr>
+                            <th style="width:150px">Code</th>
+                            <th>University Name</th>
+                            <th>Place Name</th>
+                            <th style="width:50px">Status</th>
+                            <th style="width:100px"></th>
+                        </tr>
+                    </thead>                                     
+                    <tbody id="tbl_content">
+                        <tr>
+                            <td colspan='4'>
+                                <?php echo loadingText("Loading University Names");?>
+                            </td>
+                        </tr>
+                    </tbody>
+                </table>
             </div>
-            <div class="modal-body">
-                Successfully done.
-            </div>
-            <div class="modal-footer">
-                 <button type="button" href="javascript:void(0)" onclick="dashboard()" class="btn-save">Continue</button>
-            </div>
-        </div>                                                                                                                     
+        </div>
     </div>
 </div>
 
+
 <div class="modal fade" id="confirmationtoadd" tabindex="-1" aria-labelledby="exampleModalLabel" aria-hidden="true" data-backdrop="static">
     <div class="modal-dialog modal-dialog-centered">
         <div class="modal-content">
@@ -66,7 +40,9 @@
                 <button type="button" class="btn-close" data-dismiss="modal"></button>
             </div>
             <div class="modal-body">
+             <form id="frm_create" name="frm_create" method="post" enctype="multipart/form-data" autocomplete="off">
                 <div class="row">
+                    <span id="ErrCommon"></span>
                     <div class="col-6">
                         <label class="form-label">Code</label><span style='color:red'>*</span>
                         <input class="form-control form-control-sm" type="text" id="Code" name="Code" placeholder="Code" value="" onkeypress="clearInput('Code')">
@@ -88,6 +64,7 @@
                         <span id="ErrRemarks" class="error_msg" style="color: red;"></span>
                     </div>
                 </div>
+             </form>
             </div>
             <div class="modal-footer">
                  <button type="button" data-dismiss="modal" class="btn-cancel">Cancel</button>
@@ -103,29 +80,32 @@
             <div class="modal-header">
                 <h5 class="modal-title" id="exampleModalLabel">Edit University Name</h5>
                  <button type="button" class="btn-close" data-dismiss="modal"></button>
-            </div>
+            </div>        
             <div class="modal-body">
+             <form id="frm_edit" name="frm_edit" method="post" enctype="multipart/form-data" autocomplete="off">
+             <input type="hidden" name="ID" id="editID">
                 <div class="row">
+                <span id="ErreditCommon"></span>
                     <div class="col-6">
                         <label class="form-label">Code</label><span style='color:red'>*</span>
-                        <input class="form-control form-control-sm" type="text" id="editCode" name="Code" placeholder="Code" value="<?php echo $data[0]['Code'];?>" onkeypress="clearInput('Code')">
+                        <input class="form-control form-control-sm" type="text" id="editCode" name="Code" placeholder="Code" value="" onkeypress="clearInput('Code')">
                         <span id="ErreditCode" class="error_msg" style="color: red;"></span>
                     </div>
                      <div class="col-12">
                         <label class="form-label">University Name</label><span style='color:red'>*</span>
-                         <input class="form-control form-control-sm" type="text" name="UniversityName" id="editUniversityName" placeholder="University Name" value="<?php echo $data[0]['UniversityName'];?>" onkeypress="clearInput('editUniversityName')">
+                         <input class="form-control form-control-sm" type="text" name="UniversityName" id="editUniversityName" placeholder="University Name" value="" onkeypress="clearInput('editUniversityName')">
                         <span id="ErreditUniversityName" class="error_msg" style="color: red;"></span>
                     </div>
                     <div class="col-12">
                         <label class="form-label">Place Name</label><span style='color:red'>*</span>
-                         <input class="form-control form-control-sm" type="text" name="PlaceName" id="editPlaceName" placeholder="Place Name" value="<?php echo $data[0]['PlaceName'];?>" onkeypress="clearInput('editPlaceName')">
+                         <input class="form-control form-control-sm" type="text" name="PlaceName" id="editPlaceName" placeholder="Place Name" value="" onkeypress="clearInput('editPlaceName')">
                         <span id="ErreditPlaceName" class="error_msg" style="color: red;"></span>
                     </div>
                     <div class="col-sm-6">
                         <label class="form-label">Status</label>
-                        <select name="Status" id="editStatus" class="form-select">
-                            <option value="1" <?php echo ($data[0]['Status']==1) ? " selected='selected' ": "''";?>>Active</option>
-                            <option value="0" <?php echo ($data[0]['Status']==0) ? " selected='selected' ": "''";?>>DeActive</option>
+                        <select name="Status" id="editStatus" class="form-select form-select-sm">
+                            <option value="1">Active</option>
+                            <option value="0">Deactive</option>
                         </select>
                     </div>
                     <div class="col-12">
@@ -134,6 +114,7 @@
                         <span id="ErreditRemarks" class="error_msg" style="color: red;"></span>
                     </div>
                 </div>
+             </form>
             </div>
             <div class="modal-footer">
                 <button type="button" data-dismiss="modal" class="btn-cancel">Cancel</button>
@@ -154,32 +135,32 @@
                 <div class="row">
                     <div class="col-sm-6">
                         <div style="font-weight: bold;">Code</div>
-                        <?php echo $data[0]['Code'];?>
+                        <div id="viewCode"></div>
                     </div>
                     <div class="col-sm-12">
                         <div style="font-weight: bold;">University Name</div>
-                        <?php echo $data[0]['UniversityName'];?>
+                        <div id="viewUniversityName"></div>
                     </div> 
                     <div class="col-sm-12">
                         <div style="font-weight: bold;">Place Name</div>
-                        <?php echo $data[0]['PlaceName'];?>
+                        <div id="viewPlaceName"></div>
                     </div>
                     <div class="col-sm-12">
                         <div style="font-weight: bold;">Remarks</div>
-                        <?php echo $data[0]['Remarks'];?>
+                        <div id="viewRemarks"></div>
                     </div>
                     <div class="col-sm-6">
                         <div style="font-weight: bold;">Status</div>
-                        <?php echo $data[0]['Status'];?>
+                        <div id="viewStatus"></div>
                     </div>
                     <div class="col-sm-6">
                         <div style="font-weight: bold;">Created On</div>
-                        <?php echo $data[0]['CreatedOn'];?>
+                        <div id="viewCreatedOn"></div>
                     </div>
                 </div>
             </div>
             <div class="modal-footer"> 
-                 <button type="button" data-dismiss="modal" class="btn-cancel">Cancel</button>
+                 <button type="button" data-dismiss="modal" class="btn-cancel">Close</button>
             </div>
         </div>                                                                                                                     
     </div>
@@ -192,29 +173,66 @@
                     <img id="Sucess" style="width: 150px;" src="assets/sucess.gif" alt=""/>
                 </div>
                 <h3 class="title">Success.</h3>  
-                 <button type="button" href="javascript:void(0)" onclick="dashboard()" class="btn-save">Continue</button>         
+                 <button type="button" href="javascript:void(0)" onclick="list()" class="btn-save">Continue</button>         
             </div>
         </div>
     </div>
 </div>
      
 <script>
-function view(){
-      $('#confirmation').modal("show"); 
-      
+function list() {
+      $('#Success').modal("hide");
+    $.post(URL+ "webservice.php?action=l&method=macunl","",function(data){
+      var obj = JSON.parse(data);
+        if (obj.status=="success") {
+            var html = "";
+            i=0;
+            $.each(obj.data, function (index, data) {
+                html += '<tr class="'+((i%2!=0) ? 'rEven' : 'rOdd')+'">'
+                            + '<td>' + data.Code + '</td>'
+                            + '<td>' + data.UniversityName + '</td>' 
+                            + '<td>' + data.PlaceName + '</td>' 
+                            + '<td>' + ( (data.Status=="1") ? "<span class='badge bg-success'>Active</span>" : "<span class='badge bg-secondary'>Deactive</span>" ) + '</td>'
+                            + '<td style="text-align:right">' 
+                                + '<span onclick="editform(\''+data.ID+'\')" class="editLink"  title="Edit Record"><i class="fi fi-rs-pencil"></i></span>&nbsp;&nbsp;'
+                                + '<span onclick="viewform(\''+data.ID+'\')" class="viewLink"  title="View Record"><i class="fi fi-rs-web-test"></i></span>&nbsp;&nbsp;'
+                                + '<span onclick="openDeleteConfirmation(\''+data.ID+'\',\'r\',\'macunl\',\''+data.UniversityName+'\',\'l\')" class="deleteLink" title="Delete Record"><i class="fi fi-rs-trash"></i></span>'
+                            + '</td>'
+                        + '</tr>'
+                      + '</tr>';
+                i++;
+            });
+            if(obj.data.length==0){
+            html += '<tr>'
+                + '<td colspan="4" style="text-align: center;background:#fff !important">No data found</td>'
+                + '</tr>'
+            }   
+            $('#tbl_content').html(html);
+        } else {
+             $('#popupcontent').html( error(obj.message));
+        }  
+    });
 }
 
+setTimeout("list()",2000);
+
 function addform(){
         $('#confirmationtoadd').modal("show"); 
         $('#Code').val(""); 
         $('#UniversityName').val(""); 
         $('#PlaceName').val(""); 
         $('#Remarks').val(""); 
+        
+        $('#ErrCode').html("");
+        $('#ErrUniversityName').html(""); 
+        $('#ErrPlaceName').html(""); 
+        $('#ErrRemarks').html("");
+        $('#ErrCommon').html("");
+    
         $("#Code").removeClass("highlight_error"); 
         $("#UniversityName").removeClass("highlight_error"); 
         $("#PlaceName").removeClass("highlight_error"); 
         $("#Remarks").removeClass("highlight_error"); 
-    
 }
 
 function add(){
@@ -244,21 +262,50 @@ function add(){
             $('#ErrPlaceName').html(""); 
     } 
   
-     if (error==0){
-       $('#confirmationtoadd').modal("hide"); 
-       $('#Success').modal("show");  
-    }
+     if(error==0){
+        var param = $('#frm_create').serialize();
+        $.post(URL+"webservice.php?action=a&method=macunl",param,function(data){
+        var obj = JSON.parse(data); 
+        if (obj.status=="success") {
+             $('#confirmationtoadd').modal("hide"); 
+             $('#Success').modal("show");    
+        }   else {
+            $('#ErrCommon').html(print_inlineError(obj.message));
+        }
+    });
+   }
 }
 
-function editform(){
-     $('#confirmationtoedit').modal("show"); 
-      $("#editCode").removeClass("highlight_error"); 
-      $("#editUniversityName").removeClass("highlight_error"); 
-      $("#editPlaceName").removeClass("highlight_error"); 
-      $("#editRemarks").removeClass("highlight_error");
+function editform(ID){
+     $('#confirmationtoedit').modal("show");
+     $('#ErreditCode').html("");
+     $('#ErreditUniversityName').html(""); 
+     $('#ErreditPlaceName').html(""); 
+     $('#ErreditRemarks').html(""); 
+     $("#editCode").removeClass("highlight_error"); 
+     $("#editUniversityName").removeClass("highlight_error"); 
+     $("#editPlaceName").removeClass("highlight_error"); 
+     $("#editRemarks").removeClass("highlight_error");
+      $.post(URL+ "webservice.php?action=g&method=macunl&ID="+ID,"",function(data){
+        var obj = JSON.parse(data);
+        if (obj.status=="success") {
+            var html = "";
+            $.each(obj.data, function (index, data) {
+                $('#editCode').val(data.Code);
+                $('#editID').val(data.ID);
+                $('#editUniversityName').val(data.UniversityName);
+                $('#editPlaceName').val(data.PlaceName);
+                $('#editStatus').val(data.Status);
+                $('#editRemarks').val(data.Remarks);
+            });   
+}  
+        else {
+            $('#ErreditCommon').html(print_inlineError(obj.message));
+        }
+  });
 }
 
-function edit(){
+function edit(ID){
     var error = 0;
     if ($('#editCode').val()==""){
             $('#ErreditCode').html("Please enter Code");
@@ -270,7 +317,7 @@ function edit(){
     }
      if ($('#editUniversityName').val()==""){
             $('#ErreditUniversityName').html("Please enter University Name");
-         $("#editUniversityName").addClass("highlight_error");  #dc3545";
+         $("#editUniversityName").addClass("highlight_error");
             error++;
     }  else {
         $("#editUniversityName").removeClass("highlight_error"); 
@@ -284,23 +331,43 @@ function edit(){
         $("#editPlaceName").removeClass("highlight_error"); 
             $('#ErreditPlaceName').html(""); 
     } 
-      if (error==0){
-       $('#confirmationtoedit').modal("hide"); 
-       $('#Success').modal("show");  
-    }
+      if(error==0){
+        var param = $('#frm_edit').serialize();
+        $.post(URL+"webservice.php?action=u&method=macunl",param,function(data){
+        var obj = JSON.parse(data); 
+        if (obj.status=="success") {
+             $('#confirmationtoedit').modal("hide");
+             $('#Success').modal("show");  
+        }   else {
+            $('#ErreditCommon').html(print_inlineError(obj.message));
+        }
+    });
+   }
   
 }
 
-function viewform(){
+function viewform(ID){
      $('#confirmationtoview').modal("show"); 
+       $.post(URL+ "webservice.php?action=g&method=macunl&ID="+ID,"",function(data){
+        var obj = JSON.parse(data);
+        if (obj.status=="success") {
+            $.each(obj.data, function (index, data) {
+                $('#viewCode').html(data.Code);
+                $('#viewUniversityName').html(data.UniversityName);
+                $('#viewPlaceName').html(data.PlaceName);
+                $('#viewRemarks').html(data.Remarks);
+                $('#viewCreatedOn').html(data.CreatedOn);
+               if(data.Status=="1"){
+                $('#viewStatus').html("Active");    
+               }
+               if(data.Status=="0"){
+                $('#viewStatus').html("Deactive");    
+               }
+            });   
+}  
+  }) 
 }
 
-
-
-function dashboard()  {
-  location.href='dashboard.php';                                                              
-}
- 
 //Character Limitations
  
 
@@ -340,11 +407,12 @@ for (var i=0; i<arr.length; i++) {
     if ($('#'+arr[i]).length){
         document.getElementById(arr[i]).addEventListener("keydown",function(e) {   
             var keyCode = e.keyCode || e.which;
-            if (e.ctrlKey || e.altKey) {
-                e.preventDefault();
+            if (e.ctrlKey || e.altKey) {                   
+                e.preventDefault(e.keyCode);
             } else {
+                console.log();
                 var notallowkeys = [48,49,50,51,52,53,54,55,56,57,186,187,189,173,188,190,191,59,220,221,222,219,173,61,192,111,106,109,107,46,103,104,105,100,101,102,97,98,99,96,110,190]
-                var allowedkeys  = [9,8,32,46,35,36,37,38,39,40,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,110]
+                var allowedkeys  = [190,9,8,32,46,35,36,37,38,39,40,65,66,67,68,69,70,71,72,73,74,75,76,77,78,79,80,81,82,83,84,85,86,87,88,89,90,110]
                 if (e.shiftKey) {
                     if (notallowkeys.includes(keyCode)) {
                         e.preventDefault();
