@@ -19,8 +19,8 @@
                                     <tr>
                                         <th>Code</th>
                                         <th>Area Name</th>
-                                        <th>State Name</th>
                                         <th>District Name</th>
+                                        <th>State Name</th>
                                         <th>Status</th>
                                         <th></th>
                                         <th></th>
@@ -260,7 +260,15 @@ function addform(){
      $('#StateName').val("0"); 
      $('#DistrictName').val("0"); 
      $('#AreaName').val(""); 
-     $('#Remarks').val(""); 
+     $('#Remarks').val("");
+     
+     $('#ErrCode').html(""); 
+     $('#ErrCountryName').html(""); 
+     $('#ErrStateName').html(""); 
+     $('#ErrDistrictName').html(""); 
+     $('#ErrAreaName').html(""); 
+     $('#ErrRemarks').html("");
+      
      $("#Code").removeClass("highlight_error"); 
      $("#CountryName").removeClass("highlight_error"); 
      $("#StateName").removeClass("highlight_error"); 
@@ -320,7 +328,15 @@ function add(){
 
 function editform(){
      $('#confirmationtoedit').modal("show"); 
-      $("#editCode").removeClass("highlight_error"); 
+     
+     $('#ErreditCode').html(""); 
+     $('#ErreditCountryName').html(""); 
+     $('#ErreditStateName').html(""); 
+     $('#ErreditDistrictName').html(""); 
+     $('#ErreditAreaName').html(""); 
+     $('#ErreditRemarks').html("");
+     
+     $("#editCode").removeClass("highlight_error"); 
      $("#editCountryName").removeClass("highlight_error"); 
      $("#editStateName").removeClass("highlight_error"); 
      $("#editDistrictName").removeClass("highlight_error"); 
@@ -356,11 +372,10 @@ function edit(){
     } 
     if ($('#editDistrictName').val()=="0"){
             $('#ErreditDistrictName').html("Please select District Name");
-          editDistrictName.style.border = "1px solid #dc3545";
-          document.getElementById("editDistrictName").style["boxShadow"] = "0 0 5px #dc3545";
+          $("#editDistrictName").addClass("highlight_error"); 
             error++;
     }  else {
-         document.getElementById("editDistrictName").style["boxShadow"] = "";
+          $("#editDistrictName").removeClass("highlight_error"); 
             $('#ErreditDistrictName').html(""); 
     } 
     if ($('#editAreaName').val()==""){
