@@ -3,7 +3,7 @@
                 <div class="col-xl-12 col-lg-12">
                     <div class="row">
                         <div class="col-6"> 
-                            <h3>District Name</h3>
+                            <h3>District Names</h3>
                          </div>
                          <div class="col-6" style="text-align: right;"> 
                             <button class="btn-save" onclick="addform()">New</button>
@@ -238,6 +238,13 @@ function addform(){
     $('#CountryName').val("0"); 
     $('#DistrictName').val(""); 
     $('#Remarks').val(""); 
+    
+    $('#ErrCode').html(""); 
+    $('#ErrStateName').html(""); 
+    $('#ErrCountryName').html(""); 
+    $('#ErrDistrictName').html(""); 
+    $('#ErrRemarks').html("");
+    
     $("#Code").removeClass("highlight_error"); 
     $("#StateName").removeClass("highlight_error"); 
     $("#CountryName").removeClass("highlight_error"); 
@@ -287,11 +294,16 @@ function add(){
 
 function editform(){
      $('#confirmationtoedit').modal("show"); 
-    $("#editCode").removeClass("highlight_error"); 
-    $("#editStateName").removeClass("highlight_error"); 
-    $("#editCountryName").removeClass("highlight_error"); 
-    $("#editDistrictName").removeClass("highlight_error"); 
-    $("#editRemarks").removeClass("highlight_error"); 
+     $('#ErreditCode').html(""); 
+     $('#ErreditStateName').html(""); 
+     $('#ErreditCountryName').html(""); 
+     $('#ErreditDistrictName').html(""); 
+     $('#ErreditRemarks').html("");
+     $("#editCode").removeClass("highlight_error"); 
+     $("#editStateName").removeClass("highlight_error"); 
+     $("#editCountryName").removeClass("highlight_error"); 
+     $("#editDistrictName").removeClass("highlight_error"); 
+     $("#editRemarks").removeClass("highlight_error"); 
 }
 
 function edit(){
@@ -314,10 +326,10 @@ function edit(){
     } 
       if ($('#editCountryName').val()=="0"){
             $('#ErreditCountryName').html("Please select Country Name");
-             $("#editDistrictName").addClass("highlight_error"); 
+             $("#editCountryName").addClass("highlight_error"); 
            error++;
     }  else {
-         $("#editDistrictName").removeClass("highlight_error"); 
+         $("#editCountryName").removeClass("highlight_error"); 
             $('#ErreditCountryName').html(""); 
     } 
     if ($('#editDistrictName').val()==""){
