@@ -3,7 +3,7 @@
                 <div class="col-xl-12 col-lg-12">
                     <div class="row">
                         <div class="col-6"> 
-                            <h3>State Name</h3>
+                            <h3>State Names</h3>
                          </div>
                          <div class="col-6" style="text-align: right;"> 
                             <button class="btn-save" onclick="addform()">New</button>
@@ -68,12 +68,12 @@
                 <div class="row">
                     <div class="col-6">
                         <label class="form-label">Code</label><span style='color:red'>*</span>
-                        <input class="form-control form-control-sm" type="text" id="Code" name="Code" placeholder="Code" value="" onkeypress="Code_Err()">
+                        <input class="form-control form-control-sm" type="text" id="Code" name="Code" placeholder="Code" value="" onkeypress="clearInput('Code')">
                         <span id="ErrCode" class="error_msg" style="color: red;"></span>
                     </div>
                      <div class="col-12">
                         <label class="form-label">Country Name</label><span style='color:red'>*</span>
-                         <select class="form-select form-select-sm" name="CountryName" id="CountryName" onchange="CountryName_Err()">
+                         <select class="form-select form-select-sm" name="CountryName" id="CountryName" onchange="clearInput('CountryName')">
                             <option value="0">Select Country Name</option>
                             <option value="1">Country Name</option>
                          </select>
@@ -81,12 +81,12 @@
                     </div>
                     <div class="col-12">
                         <label class="form-label">State Name</label><span style='color:red'>*</span>
-                         <input class="form-control form-control-sm" type="text" name="StateName" id="StateName" placeholder="State Name" onkeypress="StateName_Err()">
+                         <input class="form-control form-control-sm" type="text" name="StateName" id="StateName" placeholder="State Name" onkeypress="clearInput('StateName')">
                         <span id="ErrStateName" class="error_msg" style="color: red;"></span>
                     </div>
                     <div class="col-12">
                         <label class="form-label">Remarks</label>
-                        <input class="form-control form-control-sm" type="text" id="Remarks" name="Remarks" placeholder="Remarks" value="" onkeypress="Remarks_Err()">
+                        <input class="form-control form-control-sm" type="text" id="Remarks" name="Remarks" placeholder="Remarks" value="" onkeypress="clearInput('Remarks')">
                         <span id="ErrRemarks" class="error_msg" style="color: red;"></span>
                     </div>
                 </div>
@@ -110,12 +110,12 @@
                 <div class="row">
                     <div class="col-6">
                         <label class="form-label">Code</label><span style='color:red'>*</span>
-                        <input class="form-control form-control-sm" type="text" id="editCode" name="Code" placeholder="Code" value="<?php echo $data[0]['Code'];?>" onkeypress="editCode_Err()">
+                        <input class="form-control form-control-sm" type="text" id="editCode" name="Code" placeholder="Code" value="<?php echo $data[0]['Code'];?>" onkeypress="clearInput('editCode')">
                         <span id="ErreditCode" class="error_msg" style="color: red;"></span>
                     </div>
                     <div class="col-12">
                         <label class="form-label">Country Name</label><span style='color:red'>*</span>
-                         <select class="form-select form-select-sm" name="CountryName" id="editCountryName" value="<?php echo $data[0]['Country'];?>" onchange="editCountryName_Err()">
+                         <select class="form-select form-select-sm" name="CountryName" id="editCountryName" value="<?php echo $data[0]['Country'];?>" onchange="clearInput('editCountryName')">
                             <option value="0">Select Country Name</option>
                             <option value="1">Country Name</option>
                          </select>
@@ -123,14 +123,9 @@
                     </div>
                      <div class="col-12">
                         <label class="form-label">State Name</label><span style='color:red'>*</span>
-                         <input class="form-control form-control-sm" type="text" name="StateName" id="editStateName" placeholder="State Name" value="<?php echo $data[0]['StateName'];?>" onkeypress="editStateName_Err()">
+                         <input class="form-control form-control-sm" type="text" name="StateName" id="editStateName" placeholder="State Name" value="<?php echo $data[0]['StateName'];?>" onkeypress="clearInput('editStateName')">
                         <span id="ErreditStateName" class="error_msg" style="color: red;"></span>
                     </div>
-                    <div class="col-12">
-                        <label class="form-label">Remarks</label>
-                        <input class="form-control form-control-sm" type="text" id="editRemarks" name="Remarks" placeholder="Remarks" value="<?php echo $data[0]['Remarks'];?>" onkeypress="editShortCourseName_Err()">
-                        <span id="ErreditRemarks" class="error_msg" style="color: red;"></span>
-                    </div>
                     <div class="col-sm-6">
                         <label class="form-label">Status</label>
                         <select name="Status" id="editStatus" class="form-select form-select-sm">
@@ -138,6 +133,11 @@
                             <option value="0" <?php echo ($data[0]['Status']==0) ? " selected='selected' ": "''";?>>DeActive</option>
                         </select>
                     </div>
+                    <div class="col-12">
+                        <label class="form-label">Remarks</label>
+                        <input class="form-control form-control-sm" type="text" id="editRemarks" name="Remarks" placeholder="Remarks" value="<?php echo $data[0]['Remarks'];?>" onkeypress="clearInput('Code')">
+                        <span id="ErreditRemarks" class="error_msg" style="color: red;"></span>
+                    </div>
                 </div>
             </div>
                  <div class="modal-footer">
@@ -214,45 +214,41 @@ function addform(){
     $('#Code').val("");
     $('#CountryName').val("0");  
     $('#StateName').val(""); 
-    $('#Remarks').val(""); 
-      document.getElementById("Code").style["boxShadow"] = "";
-          $('#ErrCode').html("");
-          Code.style.border = "1px solid #e5dee6f7";
-          document.getElementById("CountryName").style["boxShadow"] = "";
-          $('#ErrCountryName').html("");
-          CountryName.style.border = "1px solid #e5dee6f7";
-          document.getElementById("StateName").style["boxShadow"] = "";
-          $('#ErrStateName').html("");
-          StateName.style.border = "1px solid #e5dee6f7"; 
+    $('#Remarks').val("");
+    $('#ErrCode').html(""); 
+    $('#ErrCountryName').html(""); 
+    $('#ErrStateName').html(""); 
+    $('#ErrRemarks').html(""); 
+    $("#Code").removeClass("highlight_error");  
+    $("#CountryName").removeClass("highlight_error");  
+    $("#StateName").removeClass("highlight_error");  
+    $("#Remarks").removeClass("highlight_error");  
 }
 
 function add(){
     var error = 0;
        if ($('#Code').val()==""){
             $('#ErrCode').html("Please enter Code");
-          Code.style.border = "1px solid #dc3545";
-          document.getElementById("Code").style["boxShadow"] = "0 0 5px #dc3545";
+          $("#Code").addClass("highlight_error");
            error++;
     }  else {
-         document.getElementById("Code").style["boxShadow"] = "";
+         $("#Code").removeClass("highlight_error");
             $('#ErrCode').html(""); 
     } 
     if ($('#StateName').val()==""){
             $('#ErrStateName').html("Please enter State Name");
-         StateName.style.border = "1px solid #dc3545";
-          document.getElementById("StateName").style["boxShadow"] = "0 0 5px #dc3545";
+         $("#StateName").addClass("highlight_error");  
             error++;
     }  else {
-         document.getElementById("StateName").style["boxShadow"] = "";
+         $("#StateName").removeClass("highlight_error");  
             $('#ErrStateName').html(""); 
     } 
     if ($('#CountryName').val()=="0"){
             $('#ErrCountryName').html("Please select Country Name");
-         CountryName.style.border = "1px solid #dc3545";
-          document.getElementById("CountryName").style["boxShadow"] = "0 0 5px #dc3545";
+         $("#CountryName").addClass("highlight_error");  
            error++;
     }  else {
-         document.getElementById("CountryName").style["boxShadow"] = "";
+         $("#CountryName").removeClass("highlight_error");  
           $('#ErrCountryName').html(""); 
     } 
      if (error==0){
@@ -265,44 +261,40 @@ function add(){
 
 function editform(){
      $('#confirmationtoedit').modal("show");
-       document.getElementById("editCode").style["boxShadow"] = "";
-          $('#ErreditCode').html("");
-          editCode.style.border = "1px solid #e5dee6f7";
-          document.getElementById("editCountryName").style["boxShadow"] = "";
-          $('#ErreditCountryName').html("");
-          editCountryName.style.border = "1px solid #e5dee6f7";
-          document.getElementById("editStateName").style["boxShadow"] = "";
-          $('#ErreditStateName').html("");
-          editStateName.style.border = "1px solid #e5dee6f7";
+      $("#editCode").removeClass("highlight_error");  
+      $("#editCountryName").removeClass("highlight_error");  
+      $("#editStateName").removeClass("highlight_error");  
+      $("#Remarks").removeClass("highlight_error"); 
+      $('#ErreditCode').html(""); 
+      $('#ErreditCountryName').html(""); 
+      $('#ErreditStateName').html(""); 
+      $('#ErreditRemarks').html(""); 
 }
 
 function edit(){
     var error = 0;
     if ($('#editCode').val()==""){
             $('#ErreditCode').html("Please enter Code");
-          editCode.style.border = "1px solid #dc3545";
-          document.getElementById("editCode").style["boxShadow"] = "0 0 5px #dc3545";
+          $("#editCode").addClass("highlight_error");  
             error++;
     }  else {
-         document.getElementById("editCode").style["boxShadow"] = "";
+         $("#editCode").removeClass("highlight_error");  
             $('#ErreditCode').html(""); 
     }
      if ($('#editStateName').val()==""){
             $('#ErreditStateName').html("Please enter State Name");
-          editStateName.style.border = "1px solid #dc3545";
-          document.getElementById("editStateName").style["boxShadow"] = "0 0 5px #dc3545";
+             $("#editStateName").addClass("highlight_error"); 
            error++;
     }  else {
-         document.getElementById("editStateName").style["boxShadow"] = "";
+        $("#editStateName").removeClass("highlight_error"); 
             $('#ErreditStateName').html(""); 
     }  
     if ($('#editCountryName').val()=="0"){
             $('#ErreditCountryName').html("Please select Country Name");
-          editCountryName.style.border = "1px solid #dc3545";
-          document.getElementById("editCountryName").style["boxShadow"] = "0 0 5px #dc3545";
+           $("#editCountryName").addClass("highlight_error"); 
            error++;
     }  else {
-         document.getElementById("editCountryName").style["boxShadow"] = "";
+          $("#editCountryName").removeClass("highlight_error"); 
             $('#ErreditCountryName').html(""); 
     } 
       if (error==0){
